@@ -84,6 +84,10 @@ _NclMachineStack *mstk;
 NclStackEntry  **level_1_vars;
 int	current_level_1_size;
 
+NclStackEntry  **rec_stack_entry;
+int		 max_stack_entry = NCL_STACK_SIZE;
+int		 num_stack_entry = 0;
+
 unsigned int framepntr;
 int sb_off;
 unsigned int current_scope_level = 1;
@@ -491,20 +495,20 @@ NhlErrorTypes _NclInitMachine
 	for (i = 0; i < current_level_1_size; i++) {
 		level_1_vars[i] = &(stack_entry[i]);
 	}
+
+	rec_stack_entry = (NclStackEntry**)NclCalloc(max_stack_entry, sizeof(NclStackEntry*));
+	rec_stack_entry[num_stack_entry] = stack_entry;
+	++num_stack_entry;
+
 	return(NhlNOERROR);
 }
 
 NhlErrorTypes _NclFinalizeMachine()
 {
-#if 0
-	int i;
+	int n;
 
-	for (i = 0; i < current_level_1_size; i++)
-	{
-		if(NULL != level_1_vars[i])
-			NclFree(level_1_vars[i]);
-	}
-#endif
+	for(n = 0; n < num_stack_entry; ++n)
+		NclFree(rec_stack_entry[n]);
 
 	NclFree(level_1_vars);
 
@@ -543,7 +547,7 @@ NhlErrorTypes _NclPutLevel1Var
 			return(NhlFATAL);
 		}
 		level_1_vars = tl1vars;
-		stack_entry = (NclStackEntry *)NclCalloc(NCL_LEVEL_1_SIZE,sizeof(NclStackEntry));
+		stack_entry = (NclStackEntry *)NclCalloc(current_level_1_size,sizeof(NclStackEntry));
 		if(! stack_entry) {
 			NhlPError(NhlFATAL,errno,"_NclInitMachine: Can't allocate space for machine");
 			return(NhlFATAL);
@@ -552,6 +556,14 @@ NhlErrorTypes _NclPutLevel1Var
 			level_1_vars[i + current_level_1_size] = &(stack_entry[i]);
 		}
 		current_level_1_size *= 2;
+
+		if(num_stack_entry >= max_stack_entry)
+		{
+			max_stack_entry *= 2;
+			rec_stack_entry = (NclStackEntry**)NclRealloc(rec_stack_entry, max_stack_entry*sizeof(NclStackEntry*));
+		}
+		rec_stack_entry[num_stack_entry] = stack_entry;
+		++num_stack_entry;
 	}
 	*(level_1_vars[offset]) = *therec;
 	return(NhlNOERROR);
@@ -579,7 +591,7 @@ NclStackEntry *_NclGetLevel1Var
 			return(NULL);
 		}
 		level_1_vars = tl1vars;
-		stack_entry = (NclStackEntry *)NclCalloc(NCL_LEVEL_1_SIZE,sizeof(NclStackEntry));
+		stack_entry = (NclStackEntry *)NclCalloc(current_level_1_size,sizeof(NclStackEntry));
 		if(! stack_entry) {
 			NhlPError(NhlFATAL,errno,"_NclInitMachine: Can't allocate space for machine");
 			return(NULL);
@@ -588,6 +600,14 @@ NclStackEntry *_NclGetLevel1Var
 			level_1_vars[i + current_level_1_size] = &(stack_entry[i]);
 		}
 		current_level_1_size *= 2;
+
+		if(num_stack_entry >= max_stack_entry)
+		{
+			max_stack_entry *= 2;
+			rec_stack_entry = (NclStackEntry**)NclRealloc(rec_stack_entry, max_stack_entry*sizeof(NclStackEntry*));
+		}
+		rec_stack_entry[num_stack_entry] = stack_entry;
+		++num_stack_entry;
 	}
 	return(level_1_vars[offset]);
 }
@@ -1488,7 +1508,7 @@ void _NclPrintMachine
 				_NclPrintSymbol((NclSymbol*)*ptr,fp);
 				ptr++;lptr++,fptr++;
 				fprintf(fp,"\t");
-				_NclPrintSymbol((NclSymbol*)*ptr,fp);
+				fprintf(fp,"%ld\n",(long)*ptr);
 				ptr++;lptr++,fptr++;
 				if(*(long*)ptr == 0 ) {
 					fprintf(fp,"No Subscripts");
